@@ -15,11 +15,11 @@ DBIx::ScopedTransaction - Scope database transactions on DBI handles in code, to
 
 =head1 VERSION
 
-Version 1.1.1
+Version 1.1.2
 
 =cut
 
-our $VERSION = '1.1.1';
+our $VERSION = '1.1.2';
 
 our $DESTROY_LOGGER;
 
@@ -383,8 +383,8 @@ Guillaume Aubert, C<< <aubertg at cpan.org> >>.
 
 =head1 BUGS
 
-Please report any bugs or feature requests to C<bug-dbix-scopedtransaction at rt.cpan.org>,
-or through the web interface at L<http://rt.cpan.org/NoAuth/ReportBug.html?Queue=DBIx::ScopedTransaction>.
+Please report any bugs or feature requests through the web interface at
+L<https://github.com/guillaumeaubert/DBIx-ScopedTransaction/issues/new>.
 I will be notified, and then you'll automatically be notified of progress on
 your bug as I make changes.
 
@@ -400,9 +400,9 @@ You can also look for information at:
 
 =over 4
 
-=item * RT: CPAN's request tracker
+=item * GitHub's request tracker
 
-L<http://rt.cpan.org/NoAuth/Bugs.html?Dist=DBIx::ScopedTransaction>
+L<https://github.com/guillaumeaubert/DBIx-ScopedTransaction/issues>
 
 =item * AnnoCPAN: Annotated CPAN documentation
 
@@ -412,9 +412,9 @@ L<http://annocpan.org/dist/DBIx::ScopedTransaction>
 
 L<http://cpanratings.perl.org/d/DBIx::ScopedTransaction>
 
-=item * Search CPAN
+=item * MetaCPAN
 
-L<http://search.cpan.org/dist/DBIx::ScopedTransaction/>
+L<https://metacpan.org/release/DBIx-ScopedTransaction>
 
 =back
 
@@ -428,7 +428,7 @@ for them!
 
 =head1 COPYRIGHT & LICENSE
 
-Copyright 2012 Guillaume Aubert.
+Copyright 2012-2013 Guillaume Aubert.
 
 This program is free software: you can redistribute it and/or modify it under
 the terms of the GNU General Public License version 3 as published by the Free
